@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2016-2024 -- leonerd@leonerd.org.uk
 
-package Net::Prometheus::Gauge 0.13;
+package Net::Prometheus::Gauge 0.14;
 
 use v5.14;
 use warnings;
@@ -21,6 +21,8 @@ C<Net::Prometheus::Gauge> - a snapshot value-reporting metric
 
 =head1 SYNOPSIS
 
+=for highlighter language=perl
+
    use Net::Prometheus;
 
    my $client = Net::Prometheus->new;
@@ -184,6 +186,22 @@ sub _dec_child
    $self->{values}{$labelkey} -= $delta;
 }
 
+# remove is generated automatically
+sub _remove_child
+{
+   my $self = shift;
+   my ( $labelkey ) = @_;
+
+   delete $self->{values}{$labelkey};
+}
+
+sub clear
+{
+   my $self = shift;
+
+   undef %{ $self->{values} };
+}
+
 sub samples
 {
    my $self = shift;
